@@ -1,7 +1,7 @@
 package App::lcpan::Cmd::deps_by_dependent_count;
 
-our $DATE = '2016-07-20'; # DATE
-our $VERSION = '1.001'; # VERSION
+our $DATE = '2016-08-11'; # DATE
+our $VERSION = '1.002'; # VERSION
 
 use 5.010;
 use strict;
@@ -123,7 +123,7 @@ ORDER BY COUNT(*) DESC, m.name
     while (my $row = $sth->fetchrow_hashref) {
         $row->{is_core} = $row->{module} eq 'perl' ||
             Module::CoreList::More->is_still_core(
-                $row->{module}, $row->{version},
+                $row->{module}, undef,
                 version->parse($plver)->numify);
         next if !$include_core    &&  $row->{is_core};
         next if !$include_noncore && !$row->{is_core};
@@ -148,7 +148,7 @@ App::lcpan::Cmd::deps_by_dependent_count - List dependencies, sorted by number o
 
 =head1 VERSION
 
-This document describes version 1.001 of App::lcpan::Cmd::deps_by_dependent_count (from Perl distribution App-lcpan), released on 2016-07-20.
+This document describes version 1.002 of App::lcpan::Cmd::deps_by_dependent_count (from Perl distribution App-lcpan), released on 2016-08-11.
 
 =head1 FUNCTIONS
 
